==> nextcloud-31.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ga.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Nasc poiblí",
    "Photos" : "Grianghraif",
    "On This Day" : "Ar an lá seo",
    "Your memories under your control" : "Do chuimhní cinn faoi do smacht",
    "All media" : "Na meáin go léir",
    "Videos" : "Físeáin",
    "Albums" : "Albaim",
    "Collaborative albums" : "Albam comhoibritheach",
    "People" : "Daoine",
    "Folders" : "Fillteáin",
    "Favorites" : "Ceanáin",
    "On this day" : "Ar an lá seo",
    "Shared with you" : "Roinnte leat",
    "Tags" : "Clibeanna",
    "Places" : "Áiteanna",
    "Map" : "Léarscáil",
    "Photos settings" : "Socruithe grianghraif",
    "Mark selection as favorite" : "Marcáil an roghnú mar is fearr leat",
    "Add selection to favorites" : "Cuir rogha le ceanáin",
    "Remove selection from favorites" : "Bain an rogha ó cheanáin",
    "Name of the album" : "Ainm an albam",
    "Location of the album" : "Suíomh a ar an albam",
    "Back" : "Ar ais",
    "Add collaborators" : "Cuir comhoibrithe leis",
    "Save" : "Sábháil",
    "Create album" : "Cruthaigh albam",
    "Add to Album" : "Cuir leis an Albam",
    "Add selection to album {albumName}" : "Cuir rogha leis an albam {albumName}",
    "Shared by" : "Roinnte ag",
    "Create a new album." : "Cruthaigh albam nua.",
    "Create new album" : "Cruthaigh albam nua",
    "New album" : "Albam nua",
    "_%n item_::_%n photos and videos_" : ["%n mír","%n grianghraif agus físeáin","%n grianghraif agus físeáin","%n grianghraif agus físeáin","%n grianghraif agus físeáin"],
    "Failed to fetch collaborators list." : "Theip ar liosta na gcomhoibrithe a fháil.",
    "Failed to update album." : "Theip ar an albam a nuashonrú.",
    "Add people or groups who can edit your album" : "Cuir daoine nó grúpaí leis ar féidir leo d'albam a chur in eagar",
    "Search people or groups" : "Cuardaigh daoine nó grúpaí",
    "No recommendations. Start typing." : "Gan moltaí. Tosaigh ag clóscríobh.",
    "Group" : "Grúpa",
    "Remove {collaboratorLabel} from the collaborators list" : "Bain {collaboratorLabel} de liosta na gcomhoibritheoirí",
    "Copy the public link" : "Cóipeáil an nasc poiblí",
    "Public link copied!" : "Nasc poiblí cóipeáilte!",
    "Copy public link" : "Cóipeáil nasc poiblí",
    "Delete the public link" : "Scrios an nasc poiblí",
    "Create public link share" : "Cruthaigh nasc poiblí a roinnt",
    "Share via public link" : "Roinn trí nasc poiblí",
    "This collection does not exist" : "Níl an bailiúchán seo ann",
    "An error occurred" : "Tharla earráid",
    "No picture for this day" : "Gan pictiúr don lá seo",
    "Picture taken on this day will show up here." : "Beidh pictiúr a tógadh ar an lá seo le feiceáil anseo.",
    "More photos from this day" : "Tuilleadh grianghraf ón lá seo",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n grianghraf neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta"],
    "Favorite" : "is fearr leat",
    "Favorite image, open the full size \"{name}\" image" : "An íomhá is fearr leat, oscail an íomhá iomlán \"{name}\".",
    "Open the full size \"{name}\" image" : "Oscail an íomhá iomlán \"{name}\".",
    "Select image {imageName}" : "Roghnaigh íomhá {imageName}",
    "Open the \"{name}\" folder" : "Oscail an fillteán \"{name}\".",
    "Back to {folder}" : "Ar ais go {folder}",
    "Go back" : "Dul ar ais",
    "Share this folder" : "Roinn an fillteán seo",
    "Dates" : "Dátaí",
    "Jump to specific date in list" : "Léim go dáta ar leith sa liosta",
    "Jump to {date}" : "Léim go {date}",
    "Add to {destination}" : "Cuir le { ceann scríbe}",
    "The destination folder is owned by {owner}" : "Is le {owner} an fillteán sprice",
    "There are no photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ann fós!",
    "_{years} year ago_::_{years} years ago_" : ["{years} bliain ó shin","{years} bliaina ó shin","{years} bliaina ó shin","{years} bliaina ó shin","{years} bliaina ó shin"],
    "Enable squared photos view" : "Cumasaigh amharc cearnógach ar ghrianghraif",
    "Delete source directory" : "Scrios eolaire foinse",
    "Pick folder" : "Pioc fillteán",
    "Select a source folder for your media" : "Roghnaigh fillteán foinse do na meáin",
    "All folders" : "Gach fillteáin",
    "Add a Photos source for the timelines" : "Cuir foinse Grianghraif leis do na hamlínte",
    "Add folder" : "Cuir fillteán leis",
    "Select the default upload location for your media" : "Roghnaigh an suíomh uaslódála réamhshocraithe do na meáin",
    "Home" : "Baile",
    "Choose default Photos upload and Albums location" : "Roghnaigh suíomh réamhshocraithe uaslódála Grianghraif agus Albaim",
    "Choose a different folder" : "Roghnaigh fillteán eile",
    "View" : "Amharc",
    "Media folders" : "Fillteáin meán",
    "Choose the folders from where photos and videos are shown." : "Roghnaigh na fillteáin óna dtaispeántar grianghraif agus físeáin.",
    "Upload folder" : "Uaslódáil fillteán",
    "Choose the folder where photos and albums are uploaded to." : "Roghnaigh an fillteán ina ndéantar grianghraif agus albam a uaslódáil.",
    "_%n photo_::_%n photos_" : ["%n grianghraf","%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif"],
    "Unselect all" : "Díroghnaigh go léir",
    "Add photos to this album" : "Cuir grianghraif leis an albam seo",
    "Manage collaborators for this album" : "Bainistigh comhoibrithe don albam seo",
    "Open actions menu" : "Oscail roghchlár gníomhartha",
    "Edit album details" : "Cuir sonraí albam in eagar",
    "Download all files in album" : "Íoslódáil na comhaid go léir ar an albam",
    "Delete album" : "Scriosadh albam",
    "Download selected files" : "Íoslódáil comhaid roghnaithe",
    "Remove selection from album" : "Bain an rogha ón albam",
    "This album does not have any photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ar an albam seo fós!",
    "Add photos to {albumName}" : "Cuir grianghraif le {albumName}",
    "Manage collaborators" : "Bainistigh comhoibrithe",
    "Save collaborators for this album." : "Sábháil comhoibrithe don albam seo.",
    "Cover photo for album {albumName}" : "Grianghraf clúdaigh don albam {albumName}",
    "There is no album yet!" : "Níl aon albam fós!",
    "This person could not be found" : "Níorbh fhéidir an duine seo a fháil",
    "Rename person" : "Athainmnigh duine",
    "Merge with different person" : "Cumasc le duine difriúil",
    "Download selected photos" : "Íosluchtaigh pictiúir a roghnaíodh",
    "Remove from favorites" : "Bain ó cheanáin",
    "Remove person" : "Bain duine",
    "Name of this person" : "Ainm an duine seo",
    "Save." : "Sábháil.",
    "Merge person" : "Cumaisc duine",
    "Move to different person" : "Bog chuig duine difriúil",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Bog grianghraf chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile"],
    "_Remove photo from person_::_Remove photos from person_" : ["Bain grianghraf den duine","Bain grianghraif den duine","Bain grianghraif den duine","Bain grianghraif den duine","Bain grianghraif den duine"],
    "This might take some time depending on the size of your photo library." : "Seans go dtógfaidh sé seo roinnt ama ag brath ar mhéid do leabharlann grianghraf.",
    "Recognized people will show up here" : "Taispeánfaidh daoine aitheanta anseo",
    "This folder does not exist" : "Níl an fillteán seo ann",
    "Loading folders …" : "fillteáin á lódáil…",
    "No photos in here" : "Níl aon ghrianghraif anseo",
    "Taken on {date} at {time}" : "Tógtha ar {date} ag {time}",
    "This place does not have any photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ag an áit seo fós!",
    "Add photos to this place" : "Cuir grianghraif leis an áit seo",
    "Cover photo for place {placeName}" : "Grianghraf clúdaigh don áit {placeName}",
    "There is no place yet!" : "Níl aon áit fós!",
    "Cover photo for shared album {albumName}." : "Grianghraf clúdaigh don albam comhroinnte {albumName}.",
    "Back to tags overview" : "Ar ais go forbhreathnú clibeanna",
    "No photos with this tag yet" : "Níl aon ghrianghraif leis an gclib seo fós",
    "No tags yet" : "Gan clibeanna fós",
    "Photos with tags will show up here" : "Taispeánfar grianghraif le clibeanna anseo",
    "Popular tags" : "Clibeanna Coitianta",
    "All tags" : "Gach clibeanna",
    "One of the source folders does not exist" : "Níl ceann de na fillteáin foinse ann",
    "Add to album" : "Cuir leis an albam",
    "Delete selection" : "Scrios an roghnúchán",
    "No photos or videos in here" : "Níl grianghraif nó físeáin ar bith anseo",
    "Unassigned faces" : "Aghaidheanna neamhshannta",
    "_%n photos_::_%n photos_" : ["%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif"],
    "Failed to fetch collection." : "Theip ar bhailiú a fháil.",
    "Failed to fetch collections list." : "Theip ar an liosta bailiúcháin a fháil.",
    "Failed to fetch faces list." : "Theip ar an liosta aghaidheanna a fháil.",
    "All your media" : "Na meáin go léir agat",
    "Album {title}" : "Albam {title}",
    "Shared Albums" : "Albaim Roinnte",
    "Shared album {title}" : "Albam roinnte {title}",
    "Public album {title}" : "Albam poiblí {title}",
    "Tagged photos" : "Grianghraif clibáilte",
    "Tagged photo {title}" : "Grianghraf clibáilte {title}",
    "{title}'s face" : "aghaidh {title}",
    "{startDate} to {endDate}" : "{startDate} go dtí {endDate}",
    "Details" : "Sonraí",
    "Failed to rename {oldName} to {faceName}." : "Theip ar {oldName} a athainmniú go {faceName}.",
    "Failed to delete {faceName}." : "Theip ar scriosadh {faceName}.",
    "Failed to delete {fileId}." : "Theip ar scriosadh {fileId}.",
    "Failed to delete {fileName}." : "Theip ar scriosadh {fileName}.",
    "Failed to set favorite state for {fileId}." : "Theip ar an staid is fearr leat a shocrú le haghaidh {fileId}.",
    "Failed to set favorite state for {fileName}." : "Theip ar an staid is fearr leat a shocrú le haghaidh {fileName}.",
    "Could not load photos folder" : "Níorbh fhéidir fillteán na ngrianghraf a lódáil",
    "One of the source folders does not exists" : "Níl ceann de na fillteáin foinse ann",
    "Add" : "Cuir"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-31.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ga.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Nasc poiblí",
    "Photos" : "Grianghraif",
    "On This Day" : "Ar an lá seo",
    "Your memories under your control" : "Do chuimhní cinn faoi do smacht",
    "All media" : "Na meáin go léir",
    "Videos" : "Físeáin",
    "Albums" : "Albaim",
    "Collaborative albums" : "Albam comhoibritheach",
    "People" : "Daoine",
    "Folders" : "Fillteáin",
    "Favorites" : "Ceanáin",
    "On this day" : "Ar an lá seo",
    "Shared with you" : "Roinnte leat",
    "Tags" : "Clibeanna",
    "Places" : "Áiteanna",
    "Map" : "Léarscáil",
    "Photos settings" : "Socruithe grianghraif",
    "Mark selection as favorite" : "Marcáil an roghnú mar is fearr leat",
    "Add selection to favorites" : "Cuir rogha le ceanáin",
    "Remove selection from favorites" : "Bain an rogha ó cheanáin",
    "Name of the album" : "Ainm an albam",
    "Location of the album" : "Suíomh a ar an albam",
    "Back" : "Ar ais",
    "Add collaborators" : "Cuir comhoibrithe leis",
    "Save" : "Sábháil",
    "Create album" : "Cruthaigh albam",
    "Add to Album" : "Cuir leis an Albam",
    "Add selection to album {albumName}" : "Cuir rogha leis an albam {albumName}",
    "Shared by" : "Roinnte ag",
    "Create a new album." : "Cruthaigh albam nua.",
    "Create new album" : "Cruthaigh albam nua",
    "New album" : "Albam nua",
    "_%n item_::_%n photos and videos_" : ["%n mír","%n grianghraif agus físeáin","%n grianghraif agus físeáin","%n grianghraif agus físeáin","%n grianghraif agus físeáin"],
    "Failed to fetch collaborators list." : "Theip ar liosta na gcomhoibrithe a fháil.",
    "Failed to update album." : "Theip ar an albam a nuashonrú.",
    "Add people or groups who can edit your album" : "Cuir daoine nó grúpaí leis ar féidir leo d'albam a chur in eagar",
    "Search people or groups" : "Cuardaigh daoine nó grúpaí",
    "No recommendations. Start typing." : "Gan moltaí. Tosaigh ag clóscríobh.",
    "Group" : "Grúpa",
    "Remove {collaboratorLabel} from the collaborators list" : "Bain {collaboratorLabel} de liosta na gcomhoibritheoirí",
    "Copy the public link" : "Cóipeáil an nasc poiblí",
    "Public link copied!" : "Nasc poiblí cóipeáilte!",
    "Copy public link" : "Cóipeáil nasc poiblí",
    "Delete the public link" : "Scrios an nasc poiblí",
    "Create public link share" : "Cruthaigh nasc poiblí a roinnt",
    "Share via public link" : "Roinn trí nasc poiblí",
    "This collection does not exist" : "Níl an bailiúchán seo ann",
    "An error occurred" : "Tharla earráid",
    "No picture for this day" : "Gan pictiúr don lá seo",
    "Picture taken on this day will show up here." : "Beidh pictiúr a tógadh ar an lá seo le feiceáil anseo.",
    "More photos from this day" : "Tuilleadh grianghraf ón lá seo",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n grianghraf neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta","%n grianghraif neamhshannta"],
    "Favorite" : "is fearr leat",
    "Favorite image, open the full size \"{name}\" image" : "An íomhá is fearr leat, oscail an íomhá iomlán \"{name}\".",
    "Open the full size \"{name}\" image" : "Oscail an íomhá iomlán \"{name}\".",
    "Select image {imageName}" : "Roghnaigh íomhá {imageName}",
    "Open the \"{name}\" folder" : "Oscail an fillteán \"{name}\".",
    "Back to {folder}" : "Ar ais go {folder}",
    "Go back" : "Dul ar ais",
    "Share this folder" : "Roinn an fillteán seo",
    "Dates" : "Dátaí",
    "Jump to specific date in list" : "Léim go dáta ar leith sa liosta",
    "Jump to {date}" : "Léim go {date}",
    "Add to {destination}" : "Cuir le { ceann scríbe}",
    "The destination folder is owned by {owner}" : "Is le {owner} an fillteán sprice",
    "There are no photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ann fós!",
    "_{years} year ago_::_{years} years ago_" : ["{years} bliain ó shin","{years} bliaina ó shin","{years} bliaina ó shin","{years} bliaina ó shin","{years} bliaina ó shin"],
    "Enable squared photos view" : "Cumasaigh amharc cearnógach ar ghrianghraif",
    "Delete source directory" : "Scrios eolaire foinse",
    "Pick folder" : "Pioc fillteán",
    "Select a source folder for your media" : "Roghnaigh fillteán foinse do na meáin",
    "All folders" : "Gach fillteáin",
    "Add a Photos source for the timelines" : "Cuir foinse Grianghraif leis do na hamlínte",
    "Add folder" : "Cuir fillteán leis",
    "Select the default upload location for your media" : "Roghnaigh an suíomh uaslódála réamhshocraithe do na meáin",
    "Home" : "Baile",
    "Choose default Photos upload and Albums location" : "Roghnaigh suíomh réamhshocraithe uaslódála Grianghraif agus Albaim",
    "Choose a different folder" : "Roghnaigh fillteán eile",
    "View" : "Amharc",
    "Media folders" : "Fillteáin meán",
    "Choose the folders from where photos and videos are shown." : "Roghnaigh na fillteáin óna dtaispeántar grianghraif agus físeáin.",
    "Upload folder" : "Uaslódáil fillteán",
    "Choose the folder where photos and albums are uploaded to." : "Roghnaigh an fillteán ina ndéantar grianghraif agus albam a uaslódáil.",
    "_%n photo_::_%n photos_" : ["%n grianghraf","%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif"],
    "Unselect all" : "Díroghnaigh go léir",
    "Add photos to this album" : "Cuir grianghraif leis an albam seo",
    "Manage collaborators for this album" : "Bainistigh comhoibrithe don albam seo",
    "Open actions menu" : "Oscail roghchlár gníomhartha",
    "Edit album details" : "Cuir sonraí albam in eagar",
    "Download all files in album" : "Íoslódáil na comhaid go léir ar an albam",
    "Delete album" : "Scriosadh albam",
    "Download selected files" : "Íoslódáil comhaid roghnaithe",
    "Remove selection from album" : "Bain an rogha ón albam",
    "This album does not have any photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ar an albam seo fós!",
    "Add photos to {albumName}" : "Cuir grianghraif le {albumName}",
    "Manage collaborators" : "Bainistigh comhoibrithe",
    "Save collaborators for this album." : "Sábháil comhoibrithe don albam seo.",
    "Cover photo for album {albumName}" : "Grianghraf clúdaigh don albam {albumName}",
    "There is no album yet!" : "Níl aon albam fós!",
    "This person could not be found" : "Níorbh fhéidir an duine seo a fháil",
    "Rename person" : "Athainmnigh duine",
    "Merge with different person" : "Cumasc le duine difriúil",
    "Download selected photos" : "Íosluchtaigh pictiúir a roghnaíodh",
    "Remove from favorites" : "Bain ó cheanáin",
    "Remove person" : "Bain duine",
    "Name of this person" : "Ainm an duine seo",
    "Save." : "Sábháil.",
    "Merge person" : "Cumaisc duine",
    "Move to different person" : "Bog chuig duine difriúil",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Bog grianghraf chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile","Bog grianghraif chuig duine eile"],
    "_Remove photo from person_::_Remove photos from person_" : ["Bain grianghraf den duine","Bain grianghraif den duine","Bain grianghraif den duine","Bain grianghraif den duine","Bain grianghraif den duine"],
    "This might take some time depending on the size of your photo library." : "Seans go dtógfaidh sé seo roinnt ama ag brath ar mhéid do leabharlann grianghraf.",
    "Recognized people will show up here" : "Taispeánfaidh daoine aitheanta anseo",
    "This folder does not exist" : "Níl an fillteán seo ann",
    "Loading folders …" : "fillteáin á lódáil…",
    "No photos in here" : "Níl aon ghrianghraif anseo",
    "Taken on {date} at {time}" : "Tógtha ar {date} ag {time}",
    "This place does not have any photos or videos yet!" : "Níl aon ghrianghraif nó físeáin ag an áit seo fós!",
    "Add photos to this place" : "Cuir grianghraif leis an áit seo",
    "Cover photo for place {placeName}" : "Grianghraf clúdaigh don áit {placeName}",
    "There is no place yet!" : "Níl aon áit fós!",
    "Cover photo for shared album {albumName}" : "Grianghraf clúdaigh don albam comhroinnte {albumName}",
    "Back to tags overview" : "Ar ais go forbhreathnú clibeanna",
    "No photos with this tag yet" : "Níl aon ghrianghraif leis an gclib seo fós",
    "No tags yet" : "Gan clibeanna fós",
    "Photos with tags will show up here" : "Taispeánfar grianghraif le clibeanna anseo",
    "Popular tags" : "Clibeanna Coitianta",
    "All tags" : "Gach clibeanna",
    "One of the source folders does not exist" : "Níl ceann de na fillteáin foinse ann",
    "Add to album" : "Cuir leis an albam",
    "Delete selection" : "Scrios an roghnúchán",
    "No photos or videos in here" : "Níl grianghraif nó físeáin ar bith anseo",
    "Unassigned faces" : "Aghaidheanna neamhshannta",
    "_%n photos_::_%n photos_" : ["%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif","%n grianghraif"],
    "Failed to fetch collection." : "Theip ar bhailiú a fháil.",
    "Failed to fetch collections list." : "Theip ar an liosta bailiúcháin a fháil.",
    "Failed to fetch faces list." : "Theip ar an liosta aghaidheanna a fháil.",
    "All your media" : "Na meáin go léir agat",
    "Album {title}" : "Albam {title}",
    "Shared Albums" : "Albaim Roinnte",
    "Shared album {title}" : "Albam roinnte {title}",
    "Public album {title}" : "Albam poiblí {title}",
    "Tagged photos" : "Grianghraif clibáilte",
    "Tagged photo {title}" : "Grianghraf clibáilte {title}",
    "{title}'s face" : "aghaidh {title}",
    "{startDate} to {endDate}" : "{startDate} go dtí {endDate}",
    "Details" : "Sonraí",
    "Failed to rename {oldName} to {faceName}" : "Theip ar {oldName} a athainmniú go {faceName}",
    "Failed to delete {faceName}" : "Theip ar scriosadh {faceName}",
    "Failed to delete {fileId}" : "Theip ar scriosadh {fileId}",
    "Failed to delete {fileName}" : "Theip ar scriosadh {fileName}",
    "Failed to set favorite state for {fileId}" : "Theip ar an staid is fearr leat a shocrú le haghaidh {fileId}",
    "Failed to set favorite state for {fileName}" : "Theip ar an staid is fearr leat a shocrú le haghaidh {fileName}",
    "Could not load photos folder" : "Níorbh fhéidir fillteán na ngrianghraf a lódáil",
    "One of the source folders does not exists" : "Níl ceann de na fillteáin foinse ann",
    "Add" : "Cuir"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
